<?php

namespace Litecms\SupportLibrary\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\SupportLibrary\Models\SupportMaterial;

class SupportMaterialPolicy
{

    /**
     * Determine if the given user can view the support_material.
     *
     * @param UserPolicy $user
     * @param SupportMaterial $support_material
     *
     * @return bool
     */
    public function view(UserPolicy $user, SupportMaterial $support_material)
    {
        if ($user->canDo('support_library.support_material.view') && $user->isAdmin()) {
            return true;
        }

        return $support_material->user_id == user_id() && $support_material->user_type == user_type();
    }

    /**
     * Determine if the given user can create a support_material.
     *
     * @param UserPolicy $user
     * @param SupportMaterial $support_material
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('support_library.support_material.create');
    }

    /**
     * Determine if the given user can update the given support_material.
     *
     * @param UserPolicy $user
     * @param SupportMaterial $support_material
     *
     * @return bool
     */
    public function update(UserPolicy $user, SupportMaterial $support_material)
    {
        if ($user->canDo('support_library.support_material.edit') && $user->isAdmin()) {
            return true;
        }

        return $support_material->user_id == user_id() && $support_material->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given support_material.
     *
     * @param UserPolicy $user
     * @param SupportMaterial $support_material
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, SupportMaterial $support_material)
    {
        return $support_material->user_id == user_id() && $support_material->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given support_material.
     *
     * @param UserPolicy $user
     * @param SupportMaterial $support_material
     *
     * @return bool
     */
    public function verify(UserPolicy $user, SupportMaterial $support_material)
    {
        if ($user->canDo('support_library.support_material.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given support_material.
     *
     * @param UserPolicy $user
     * @param SupportMaterial $support_material
     *
     * @return bool
     */
    public function approve(UserPolicy $user, SupportMaterial $support_material)
    {
        if ($user->canDo('support_library.support_material.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
