<?php

namespace Litecms\SupportLibrary\Providers;

use Illuminate\Support\ServiceProvider;

class SupportLibraryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'support_library');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'support_library');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.support_library', function ($app) {
            return $this->app->make('Litecms\SupportLibrary\SupportLibrary');
        });

                // Bind SupportMaterial to repository
        $this->app->bind(
            'Litecms\SupportLibrary\Interfaces\SupportMaterialRepositoryInterface',
            \Litecms\SupportLibrary\Repositories\Eloquent\SupportMaterialRepository::class
        );

        $this->app->register(\Litecms\SupportLibrary\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\SupportLibrary\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\SupportLibrary\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.support_library'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/support_library.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/support_library')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/support_library')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
